//+------------------------------+
//|   Manual_Delay               |
//+==============================+
//|
//|   Rev Date: 2010.12.13
//|
//|   Contains the following Functions:
//|
//|   IsTestingDelay()
//|
//+------------------------------+

#property copyright "1005phillip"

#include <stderror.mqh>
#include <stdlib.mqh>

//+------------------------------+
//|   IsTestingDelay()           |
//|==============================+
//|   void IsTestingDelay(double target_delay,bool verbose=false)
//|
//|   Loops through a counter that is designed to produce a effective delay similar to that of sleeping
//|
//|   Parameters:
//|
//|      target_delay   -  A target value for the desired delay in millseconds
//|      verbose        -  Determines whether Print messages are committed to the experts log. By default, print messages are disabled.
//|
//|   Sample:
//|
//|      IsTestingDelay(1500);     // force a delay of approximately 1.5 seconds while in backtesting
//|
//+------------------------------+
void IsTestingDelay(double target_delay,bool verbose=false)
   {  // IsTestingDelay body start
   
   double reference_time=19.5*1000.;    // time in seconds require to process the loop in a 2.4GHz Core 2 Duo Q6600
   
   double delay_ratio=MathMin(target_delay/reference_time,1.); // Don't let the ratio exceed 1
   
   int k_initial=-2147483648*delay_ratio;
   int k_final=2147483646*delay_ratio;
   int k=0;
   double start;
   
   k=k_initial;
   start=1.*GetTickCount();
   
   if(verbose==true) Print("k = ",k);
   while(k<k_final)
      {
      k++;
      }
   if(verbose==true) Print("k = ",k);
   if(verbose==true) Print("Calculation time was ", DoubleToStr((1.*GetTickCount()-1.*start)/1000.,4), " seconds (", GetTickCount()-start, " milliseconds), targeted delay time was target_delay = ",target_delay," milliseconds");
   
   return(0);
   
   }  // IsTestingDelay body end

// Function End

/*
   +------------------------------------------------------------------+
   |                                                                  |
   |   Revision History                                               |
   |                                                                  |
   +------------------------------------------------------------------+

 Objective: This include file contains the routine necessary for inducing a real-world delay in the execution of the EA by performing a CPU intensive loop-counter
            
 Future Work:  tbd
            
 2010 Worklog:
   
   Dec 13   Creating IsTestingDelay()
   
*/


